@@ -5,33 +5,33 @@
 #' 
 #' @description
 #' 
-#' To compare \eqn{gh}-parsimonious models of Tukey's \eqn{g}-&-\eqn{h} mixtures with different number of components \eqn{K} 
-#' (up to a user-specified \eqn{K_{max}})
+#' To compare \eqn{gh}-parsimonious models of Tukey \eqn{g}-&-\eqn{h} mixtures with different number of components \eqn{K} 
+#' (up to a user-specified \eqn{K_\text{max}})
 #' and select the optimal number of components.
 #' 
 #' @param x \link[base]{numeric} \link[base]{vector}, observations
 #' 
 #' @param distname,data.name \link[base]{character} scalars, 
-#' see parameters of the same names in function [QLMDe()]
+#' see parameters of the same names in function [QLMDe]
 #' 
-#' @param direction \link[base]{character} scalar, direct of selection in function [step_fmx()], 
+#' @param direction \link[base]{character} scalar, direct of selection in function [step_fmx], 
 #' either `'forward'` (default) or `'backward'`
 #' 
 #' @param test \link[base]{character} scalar, criterion to be used, either 
 #' Akaike's information criterion \link[stats]{AIC}, or 
 #' Bayesian information criterion \link[stats]{BIC} (default).
 #' 
-#' @param Kmax \link[base]{integer} scalar \eqn{K_{max}}, 
+#' @param Kmax \link[base]{integer} scalar \eqn{K_\text{max}}, 
 #' maximum number of components to be considered. Default `3L`
 #' 
 #' @param ... additional parameters
 #' 
 #' @details 
 #' 
-#' Function [QLMDe_stepK()] compares the \eqn{gh}-parsimonious models with different number of components \eqn{K},
+#' Function [QLMDe_stepK] compares the \eqn{gh}-parsimonious models with different number of components \eqn{K},
 #' and selects the optimal number of components using BIC (default) or AIC.
 #' 
-#' The forward selection starts with finding the \eqn{gh}-parsimonious model (via function [step_fmx()])
+#' The forward selection starts with finding the \eqn{gh}-parsimonious model (via function [step_fmx])
 #' at \eqn{K = 1}.   
 #' Let the current number of component be \eqn{K^c}.  
 #' We compare the \eqn{gh}-parsimonious models of \eqn{K^c+1} and \eqn{K^c} component, respectively,
@@ -45,15 +45,15 @@
 #' 
 #' @returns 
 #' 
-#' Function [QLMDe_stepK()] returns an object of S3 class `'stepK'`, 
+#' Function [QLMDe_stepK] returns an object of S3 class `'stepK'`, 
 #' which is a \link[base]{list} of selected models (in reversed order) with attribute(s)
 #' `'direction'` and
 #' `'test'`.
 #' 
 #' @examples 
-#' 
-#' hist(x1 <- CK5[[1L]])
-#' \donttest{QLMDe_stepK(x1, distname = 'GH', Kmax = 2L)}
+#' data(bmi, package = 'mixsmsn')
+#' hist(x <- bmi[[1L]])
+#' \donttest{QLMDe_stepK(x, distname = 'GH', Kmax = 2L)}
 #' 
 #' @export
 QLMDe_stepK <- function(
@@ -94,6 +94,7 @@ QLMDe_stepK <- function(
 }
 
 
+#' @importFrom fmx print.fmx npar.fmx getTeX
 #' @export
 print.stepK <- function(x, ...) {
   print.fmx(x[[1L]])
@@ -102,7 +103,7 @@ print.stepK <- function(x, ...) {
   tb <- data.frame( # this is *not* an 'anova' table!!
     '# Parameter' = vapply(x, FUN = npar.fmx, FUN.VALUE = 0L), 
     test = vapply(x, FUN = match.fun(test), FUN.VALUE = 0), 
-    row.names = vapply(x, FUN = getTeX, FUN.VALUE = ''), 
+    row.names = vapply(x, FUN = getTeX, print_K = TRUE, FUN.VALUE = ''), 
     check.names = FALSE)
   names(tb)[2L] <- test
   print.data.frame(tb)
