@@ -14,12 +14,13 @@
 #' @details ..
 #' 
 #' @note 
-#' Note that [drop1.fmx] and [add1.fmx] do *not* return an \link[stats]{anova} table, like other
+#' Functions [drop1.fmx] and [add1.fmx] do *not* 
+#' return an \link[stats]{anova} table, like other
 #' `stats:::drop.*` or `stats:::add1.*` functions do.
 #' 
 #' @returns
 #' 
-#' [drop1.fmx] and [add1.fmx] return a \link[base]{list} of \linkS4class{fmx} objects,
+#' Functions [drop1.fmx] and [add1.fmx] return a \link[base]{list} of \linkS4class{fmx} objects,
 #' in the reverse order of model selection.
 #' 
 #' @seealso 
@@ -29,11 +30,10 @@
 #' @examples 
 #' 
 #' \donttest{ 
-#' 
 #' # donttest to save time
-#' 
+#' library(fmx)
 #' (d2 = fmx('GH', A = c(1,6), B = 1.2, g = c(0,.3), h = c(.2,0), w = c(1,2)))
-#' set.seed(3123); hist(x2 <- rfmx(n = 1e3L, dist = d2))
+#' set.seed(312); hist(x2 <- rfmx(n = 1e3L, dist = d2))
 #' system.time(m0 <- QLMDe(x2, distname = 'GH', K = 2L, constraint = c('g1', 'g2', 'h1', 'h2')))
 #' system.time(m1 <- QLMDe(x2, distname = 'GH', K = 2L, constraint = c('g1', 'h2')))
 #' system.time(m2 <- QLMDe(x2, distname = 'GH', K = 2L)) # ~2 secs
@@ -50,13 +50,15 @@
 #' 
 #' }
 #' 
-#' @importFrom stats drop1
 #' @name drop1_fmx
+#' @importFrom fmx fmx_constraint
+#' @importFrom stats drop1
 #' @export drop1.fmx
 #' @export
 drop1.fmx <- function(object, ...) {
   if (!length(object@data)) return(invisible())
   K <- dim(object@pars)[1L]
+  probs <- attr(object, which = 'probs', exact = TRUE)
   
   # existing constraint of `object`, to be respected
   constr_ <- attr(fmx_constraint(object), which = 'user', exact = TRUE)
@@ -70,7 +72,7 @@ drop1.fmx <- function(object, ...) {
   mods0 <- lapply(candpar, FUN = function(i) {
     i <- c(constr_, i)
     message(paste0(object@distname, K), ' ', paste(c(i, '0'), collapse = '='), ' .. ', appendLF = FALSE)
-    ret <- QLMDe(object@data, data.name = object@data.name, distname = object@distname, K = K, probs = object@probs, constraint = i)
+    ret <- QLMDe(object@data, data.name = object@data.name, distname = object@distname, K = K, probs = probs, constraint = i)
     message('done!')
     return(ret)
   })
@@ -84,13 +86,15 @@ drop1.fmx <- function(object, ...) {
 
 
 # need to re-use the examples, to save time!
-#' @importFrom stats add1
 #' @rdname drop1_fmx
+#' @importFrom fmx fmx_constraint
+#' @importFrom stats add1
 #' @export add1.fmx
 #' @export
 add1.fmx <- function(object, ...) {
   if (!length(object@data)) return(invisible())
   K <- dim(object@pars)[1L]
+  probs <- attr(object, which = 'probs', exact = TRUE)
   
   # existing constraint of `object` (i.e., candidate parameter(s) to be added)
   constr_ <- attr(fmx_constraint(object), which = 'user', exact = TRUE)
@@ -99,7 +103,7 @@ add1.fmx <- function(object, ...) {
   mods0 <- lapply(seq_along(constr_), FUN = function(i) {
     i <- constr_[-i] # remove one constraint parameter
     message(paste0(object@distname, K), ' ', if (length(i)) paste(c(i, '0'), collapse = '='), ' .. ', appendLF = FALSE)
-    ret <- QLMDe(object@data, data.name = object@data.name, distname = object@distname, K = K, probs = object@probs, constraint = i)
+    ret <- QLMDe(object@data, data.name = object@data.name, distname = object@distname, K = K, probs = probs, constraint = i)
     message('done!')
     return(ret)
   })
